@@ -69,7 +69,7 @@ API Reference
 
 # stdlib
 import warnings
-from typing import Any, Dict,  Sequence, Type
+from typing import Any, Dict, Sequence, Type
 
 # 3rd party
 from docutils import nodes
@@ -201,7 +201,7 @@ def parse_conf_node(env: BuildEnvironment, text: str, node: addnodes.desc_signat
 
 def setup(app: Sphinx) -> Dict[str, Any]:
 	"""
-	Setup Sphinx Extension
+	Setup Sphinx Extension.
 
 	:param app: The Sphinx app
 	"""
