@@ -30,11 +30,8 @@ Metaclass for configuration values.
 from abc import abstractmethod
 from typing import TYPE_CHECKING, Any, Callable, Dict, Mapping, Optional, Type, cast
 
-# 3rd party
-from typing_inspect import get_origin  # type: ignore
-
 # this package
-from configconfig.utils import get_json_type
+from configconfig.utils import basic_schema, get_json_type
 
 __all__ = ["ConfigVarMeta"]
 
@@ -59,17 +56,22 @@ class ConfigVarMeta(type):
 	def __new__(cls, name: str, bases, dct: Dict):
 		x = cast("ConfigVar", super().__new__(cls, name, bases, dct))
 
-		x.dtype = dct.get("dtype", Any)
+		def get(name, default):
+			return dct.get(name, getattr(x, name, default))
+
+		x.dtype = get("dtype", Any)
 
 		if "rtype" in dct:
 			x.rtype = dct["rtype"]
+		elif getattr(x, "rtype", Any) != Any:
+			pass
 		else:
 			x.rtype = x.dtype
 
-		x.required = dct.get("required", False)
-		x.default = dct.get("default", '')
-		x.validator = dct.get("validator", lambda y: y)  # type: ignore
-		x.category = dct.get("category", "other")
+		x.required = get("required", False)
+		x.default = get("default", '')
+		x.validator = get("validator", lambda y: y)  # type: ignore
+		x.category = get("category", "other")
 		x.__name__ = dct.get("name", dct.get("__name__", x.__name__))  # type: ignore
 
 		return x
@@ -85,17 +87,26 @@ class ConfigVarMeta(type):
 
 		if schema is None:
 			schema = {
-					"$schema": "http://json-schema.org/schema#",
-					"type": "object",
+					**basic_schema,
 					"properties": {},
 					"required": [],
 					}
 
-		schema["properties"][cls.__name__] = get_json_type(cls.dtype)
+		dtype = get_json_type(cls.dtype)
+		if dtype is NotImplemented:
+			raise NotImplementedError(cls.__name__, cls.dtype)
+		else:
+			schema["properties"][cls.__name__] = dtype
 
 		if cls.required:
 			schema["required"].append(cls.__name__)
 
+		for line in (cls.__doc__ or '').split("\n\n"):
+			line = " ".join([p.strip() for p in line.split("\n") if p.strip()])
+			if line:
+				schema["properties"][cls.__name__]["description"] = line
+				break
+
 		return schema
 
 	@property
