@@ -2,7 +2,7 @@
 #
 #  utils.py
 """
-Utility functions
+Utility functions.
 """
 #
 #  Copyright © 2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
@@ -25,11 +25,20 @@ Utility functions
 #  OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE
 #  OR OTHER DEALINGS IN THE SOFTWARE.
 #
+#  gat_args based on CPython.
+#  Licensed under the Python Software Foundation License Version 2.
+#  Copyright © 2001-2020 Python Software Foundation. All rights reserved.
+#  Copyright © 2000 BeOpen.com . All rights reserved.
+#  Copyright © 1995-2000 Corporation for National Research Initiatives . All rights reserved.
+#  Copyright © 1991-1995 Stichting Mathematisch Centrum . All rights reserved.
+#
 
 # stdlib
 import copy
 import sys
+import typing
 from enum import EnumMeta
+from types import MappingProxyType
 from typing import TYPE_CHECKING, Any, Callable, Dict, List, Type, TypeVar, Union
 
 # 3rd party
@@ -72,11 +81,26 @@ else:  # pragma: no cover (>=py38)
 		return ()
 
 
-__all__ = ["optional_getter", "get_yaml_type", "make_schema", "check_union", "get_json_type", "tab"]
+__all__ = [
+		"get_literal_values",
+		"basic_schema",
+		"optional_getter",
+		"get_yaml_type",
+		"make_schema",
+		"check_union",
+		"get_json_type",
+		"tab",
+		]
 
+#: A literal ``TAB`` (``\t``) character for use in f-strings.
 tab = "\t"
-UnionType = type(Union)
-GenericAliasType = type(List)
+
+if sys.version_info < (3, 7):
+	UnionType = Any
+	GenericAliasType = Any
+else:
+	UnionType = type(Union)
+	GenericAliasType = type(List)
 
 
 def optional_getter(raw_config_vars: Dict[str, Any], cls: "ConfigVarMeta", required: bool) -> Any:
@@ -103,6 +127,7 @@ def optional_getter(raw_config_vars: Dict[str, Any], cls: "ConfigVarMeta", requi
 				return copy.deepcopy(cls.default)
 
 
+#: Mapping of Python types to their YAML equivalents.
 yaml_type_lookup = {
 		str: "String",
 		int: "Integer",
@@ -114,11 +139,15 @@ yaml_type_lookup = {
 		}
 
 
+def check_type(left: Type, *right: Type):
+	return left in right or get_origin(left) in right
+
+
 def get_yaml_type(type_: Type) -> str:
-	"""
+	r"""
 	Get the YAML type that corresponds to the given Python type.
 
-	:param type_:
+	:param type\_:
 	"""
 
 	if type_ in yaml_type_lookup:
@@ -128,15 +157,23 @@ def get_yaml_type(type_: Type) -> str:
 		dtype = " or ".join(yaml_type_lookup[x] for x in type_.__args__)
 		return dtype
 
-	elif get_origin(type_) in {list, List}:
-		inner_types = (get_yaml_type(x) for x in get_args(type_) if not isinstance(x, TypeVar))
+	elif check_type(type_, list, List):
+		args = get_args(type_)
+
+		inner_types: typing.Iterable[str]
+
+		if args:
+			inner_types = (get_yaml_type(x) for x in args if not isinstance(x, TypeVar))
+		else:
+			inner_types = ()
+
 		dtype = " or ".join(inner_types)
 		if dtype:
 			return f"Sequence of {dtype}"
 		else:
 			return "Sequence"
 
-	elif get_origin(type_) in {dict, Dict}:
+	elif check_type(type_, dict, Dict):
 		args = get_args(type_)
 		if not args or any(isinstance(t, TypeVar) for t in args):
 			return "Mapping"
@@ -145,7 +182,7 @@ def get_yaml_type(type_: Type) -> str:
 			return f"Mapping of {dtype}"
 
 	elif is_literal_type(type_):
-		types = [y for y in type_.__args__]
+		types = [y for y in get_literal_values(type_)]
 		return " or ".join(repr(x) for x in types)
 
 	elif isinstance(type_, EnumMeta):
@@ -155,6 +192,12 @@ def get_yaml_type(type_: Type) -> str:
 		return str(type_)
 
 
+basic_schema = MappingProxyType({
+		"$schema": "http://json-schema.org/draft-07/schema",
+		"type": "object",
+		})
+
+
 def make_schema(*configuration_variables: "ConfigVarMeta") -> Dict[str, Any]:
 	"""
 	Create a ``JSON`` schema from a list of :class:`~configconfig.class.ConfigVar` classes.
@@ -165,8 +208,7 @@ def make_schema(*configuration_variables: "ConfigVarMeta") -> Dict[str, Any]:
 	"""
 
 	schema = {
-			"$schema": "http://json-schema.org/schema#",
-			"type": "object",
+			**basic_schema,
 			"properties": {},
 			"required": [],
 			"additionalProperties": False,
@@ -203,10 +245,10 @@ def get_json_type(type_: Type) -> Dict[str, Union[str, List, Dict]]:
 	elif get_origin(type_) is Union:
 		return {"type": [get_json_type(t)["type"] for t in type_.__args__]}
 
-	elif get_origin(type_) in {list, List}:
+	elif check_type(type_, list, List):
 		args = get_args(type_)
-		if args:
 
+		if args:
 			items = get_json_type(args[0])
 
 			if items is NotImplemented:
@@ -220,11 +262,11 @@ def get_json_type(type_: Type) -> Dict[str, Union[str, List, Dict]]:
 
 		return {"type": "array"}
 
-	elif get_origin(type_) in {dict, Dict}:
+	elif check_type(type_, dict, Dict):
 		return {"type": "object"}
 
-	elif get_origin(type_) is Literal:
-		return {"enum": [x for x in type_.__args__]}
+	elif check_type(type_, Literal) or is_literal_type(type_):  # type: ignore
+		return {"enum": [x for x in get_literal_values(type_)]}
 
 	elif isinstance(type_, EnumMeta):
 		return {"enum": [x._value_ for x in type_]}  # type: ignore
@@ -236,6 +278,7 @@ def get_json_type(type_: Type) -> Dict[str, Union[str, List, Dict]]:
 		return NotImplemented
 
 
+#: Mapping of Python types to their JSON equivalents.
 json_type_lookup = {
 		str: "string",
 		int: "number",
@@ -243,3 +286,18 @@ json_type_lookup = {
 		dict: "object",
 		list: "array",
 		}
+
+
+def get_literal_values(literal: Literal) -> typing.Tuple[Any]:  # type: ignore
+	"""
+	Returns a tuple of permitted values for a :class:`typing.Literal`.
+
+	:param literal:
+
+	.. versionadded:: 0.3.0
+	"""
+
+	if sys.version_info < (3, 7):
+		return literal.__values__
+	else:
+		return literal.__args__
